@@ -23,16 +23,14 @@ CFReader_new(InvIndex *invindex, SegInfo *seg_info)
     }
 
     /* assign */
-    REFCOUNT_INC(invindex);
-    REFCOUNT_INC(seg_info);
-    self->invindex  = invindex;
-    self->seg_info  = seg_info;
+    self->invindex  = REFCOUNT_INC(invindex);
+    self->seg_info  = REFCOUNT_INC(seg_info);
 
     /* retrieve entries */
     self->entries = (Hash*)Hash_Fetch(metadata, "sub_files", 9);
     if (self->entries == NULL)
         CONFESS("Failed to extract 'sub_files' from compound_file metadata");
-    REFCOUNT_INC(self->entries);
+    (void)REFCOUNT_INC(self->entries);
 
     /* open an instream which we'll clone over and over */
     BB_Cat_Str(filename, ".cf", 3);
