@@ -7,7 +7,7 @@
 #include "KinoSearch/Posting.r"
 #include "KinoSearch/Posting/RawPosting.r"
 #include "KinoSearch/Schema.r"
-#include "KinoSearch/Schema/FieldSpec.r"
+#include "KinoSearch/FieldSpec.r"
 #include "KinoSearch/Index/PostingPoolQueue.r"
 #include "KinoSearch/Index/SegInfo.r"
 #include "KinoSearch/Index/Term.r"
@@ -49,22 +49,17 @@ PostPool_new(Schema *schema, const ByteBuf *field_name,
     self->scratch_cap      = 0;
 
     /* assign */
-    REFCOUNT_INC(term_stepper);
-    REFCOUNT_INC(schema);
-    REFCOUNT_INC(mem_pool);
-    self->schema         = schema;
-    self->mem_pool       = mem_pool;
-    self->term_stepper   = term_stepper;
+    self->schema         = REFCOUNT_INC(schema);
+    self->mem_pool       = REFCOUNT_INC(mem_pool);
+    self->term_stepper   = REFCOUNT_INC(term_stepper);
     self->field_name     = BB_CLONE(field_name);
-    if (pre_sort_remap != NULL) {
-        REFCOUNT_INC(pre_sort_remap);
-        self->context = (Obj*)pre_sort_remap;
-    }
+    if (pre_sort_remap != NULL)
+        self->context = (Obj*)REFCOUNT_INC(pre_sort_remap);
 
     /* derive */
     self->posting = Schema_Fetch_Posting(schema, field_name);
     self->fspec   = Schema_Fetch_FSpec(schema, field_name);
-    REFCOUNT_INC(self->fspec);
+    (void)REFCOUNT_INC(self->fspec);
 
     return self;
 }
@@ -136,8 +131,7 @@ PostPool_assign_seg(PostingPool *self, Folder *other_folder,
 
         /* assign doc base and doc map */
         self->doc_base = doc_base;
-        REFCOUNT_INC(doc_map);
-        self->doc_map  = doc_map;
+        self->doc_map  = REFCOUNT_INC(doc_map);
     }
     else {
         /* this posting pool will be empty */
@@ -271,6 +265,7 @@ PostPool_refill(PostingPool *self)
         /* read a posting from the input stream */
         raw_posting = Post_Read_Raw(main_posting, post_instream, 
             self->last_doc_num, term_text, mem_pool);
+        self->last_doc_num = raw_posting->doc_num;
         self->post_count--;
 
         /* skip deletions */
@@ -287,7 +282,6 @@ PostPool_refill(PostingPool *self)
             PostPool_Grow_Cache(self, num_elems);
         }
         self->cache[ num_elems ] = (Obj*)raw_posting;
-        self->last_doc_num = raw_posting->doc_num;
         num_elems++;
     }
 
