@@ -6,7 +6,7 @@
 
 #include "KinoSearch/Posting.r"
 #include "KinoSearch/Schema.r"
-#include "KinoSearch/Schema/FieldSpec.r"
+#include "KinoSearch/FieldSpec.r"
 #include "KinoSearch/Index/DelDocs.r"
 #include "KinoSearch/Index/SegInfo.r"
 #include "KinoSearch/Index/SkipStepper.r"
@@ -43,18 +43,12 @@ SegPList_new(Schema *schema, Folder *folder, SegInfo *seg_info,
     self->skip_stream     = NULL;
 
     /* assign */
-    REFCOUNT_INC(schema);
-    REFCOUNT_INC(folder);
-    REFCOUNT_INC(seg_info);
-    if (deldocs != NULL)
-        REFCOUNT_INC(deldocs);
-    REFCOUNT_INC(lex_reader);
-    self->schema          = schema;
-    self->folder          = folder;
-    self->seg_info        = seg_info;
+    self->schema          = REFCOUNT_INC(schema);
+    self->folder          = REFCOUNT_INC(folder);
+    self->seg_info        = REFCOUNT_INC(seg_info);
     self->field           = BB_CLONE(field);
-    self->deldocs         = deldocs;
-    self->lex_reader      = lex_reader;
+    self->deldocs         = deldocs == NULL ? NULL : REFCOUNT_INC(deldocs);
+    self->lex_reader      = REFCOUNT_INC(lex_reader);
     self->skip_interval   = skip_interval;
     
     /* derive */
@@ -137,52 +131,6 @@ SegPList_set_doc_base(SegPostingList *self, u32_t doc_base)
     self->doc_base = doc_base;
 }
 
-u32_t 
-SegPList_bulk_read(SegPostingList *self, ByteBuf *postings, 
-                      u32_t num_wanted)
-{
-    u32_t num_got = 0;
-    InStream *const post_stream = self->post_stream;
-    DelDocs  *const deldocs     = self->deldocs;
-    Posting  *const posting     = self->posting;
-    const u32_t     doc_base    = self->doc_base;
-
-    /* cap num_wanted by how many we can supply at maximum */
-    if (num_wanted > self->doc_freq - self->count)
-        num_wanted = self->doc_freq - self->count;
-
-    do {
-        Posting *temp;
-
-        /* do a raw read */
-        num_got = Post_Bulk_Read(posting, post_stream, postings, num_wanted); 
-        self->count += num_got;
-
-        /* if no deldocs, no need to process deletions */
-        if (deldocs == NULL)
-            break;
-
-        /* process deletions by splicing them out of linked list */
-        temp = (Posting*)postings->ptr;
-        while (temp != NULL) {
-            Posting *next = temp->next;
-            while (next != NULL) {
-                const u32_t doc_minus_base = next->doc_num - doc_base;
-                if (!DelDocs_Get(deldocs, doc_minus_base))
-                    break;
-                next = next->next;
-                num_got--;
-            }
-            temp->next = next;
-            temp = next;
-        }
-
-    /* only loop again if all docs found were deleted and we have more */
-    } while (num_got == 0 && self->count < self->doc_freq);
-
-    return num_got;
-}
-
 bool_t
 SegPList_next(SegPostingList *self) 
 {
