@@ -10,10 +10,8 @@ MatchPosting*
 MatchPost_new(Similarity *sim)
 {
     CREATE(self, MatchPosting, MATCHPOSTING);
-    self->next    = NULL;
-    self->doc_num = DOC_NUM_SENTINEL;
-    REFCOUNT_INC(sim);
-    self->sim = sim;
+    self->doc_num     = DOC_NUM_SENTINEL;
+    self->sim         = REFCOUNT_INC(sim);
     return self;
 }
 
