@@ -20,12 +20,9 @@ ANDNOTScorer_new(Similarity *sim, Scorer *and_scorer, Scorer *not_scorer)
     CREATE(self, ANDNOTScorer, ANDNOTSCORER);
 
     /* assign */
-    REFCOUNT_INC(sim);
-    REFCOUNT_INC(and_scorer);
-    REFCOUNT_INC(not_scorer);
-    self->sim              = sim;
-    self->and_scorer       = and_scorer;
-    self->not_scorer       = not_scorer;
+    self->sim              = REFCOUNT_INC(sim);
+    self->and_scorer       = REFCOUNT_INC(and_scorer);
+    self->not_scorer       = REFCOUNT_INC(not_scorer);
 
     /* init */
     self->first_time       = true;
@@ -77,9 +74,9 @@ ANDNOTScorer_skip_to(ANDNOTScorer *self, u32_t target)
 
     /* if no more exclusions, return anything from the required scorer */
     if (self->not_scorer == NULL)
-        return Scorer_Next(self->and_scorer);
+        return Scorer_Skip_To(self->and_scorer, target);
 
-    if ( Scorer_Next(self->and_scorer) ) {
+    if ( Scorer_Skip_To(self->and_scorer, target) ) {
         return to_non_excluded(self);
     }
     else {
