@@ -19,7 +19,7 @@ struct kino_MatchFieldScorer {
     KINO_SCORER_MEMBER_VARS;
     struct kino_Tally    *tally;
     struct kino_IntMap   *sort_cache;
-    chy_u32_t             doc_num;
+    chy_i32_t             doc_num;
     struct kino_Native   *weight;
 };
 
