@@ -20,10 +20,8 @@ ORScorer_new(Similarity *sim, VArray *subscorers)
     CREATE(self, ORScorer, ORSCORER);
 
     /* assign */
-    REFCOUNT_INC(sim);
-    REFCOUNT_INC(subscorers);
-    self->sim              = sim;
-    self->subscorers       = subscorers;
+    self->sim              = REFCOUNT_INC(sim);
+    self->subscorers       = REFCOUNT_INC(subscorers);
 
     /* init */
     self->doc_num          = DOC_NUM_SENTINEL;  /* really ought to be -1 */
