@@ -17,7 +17,6 @@ struct kino_Tally;
 struct kino_ScoreProx;
 struct kino_Posting;
 struct kino_PostingList;
-struct kino_HitCollector;
 struct kino_Native;
 
 #define KINO_TERMSCORER_SCORE_CACHE_SIZE 32
@@ -37,7 +36,6 @@ struct kino_TermScorer {
     struct kino_Tally        *tally;
     struct kino_ScoreProx    *sprox;
     struct kino_PostingList  *plist;
-    struct kino_ByteBuf      *postings;
     struct kino_Posting      *posting;
 };
 
