@@ -1,4 +1,3 @@
-#define KINO_USE_SHORT_NAMES
 #include "KinoSearch/Util/ToolSet.h"
 
 #include <errno.h>
@@ -6,48 +5,48 @@
 #define KINO_WANT_FILEDES_VTABLE
 #include "KinoSearch/Store/FileDes.r"
 
-i32_t kino_FileDes_global_count = 0;
+i32_t kino_FileDes_object_count = 0;
+i32_t kino_FileDes_open_count = 0;
 
-void
+bool_t
 FileDes_fdseek(FileDes *self, u64_t target)
 {
-    UNUSED_VAR(self);
     UNUSED_VAR(target);
-    CONFESS("FileDes_FDSeek must be defined in a subclass");
+    ABSTRACT_DEATH(self, "FDSeek");
+    UNREACHABLE_RETURN(bool_t);
 }
 
-void
+bool_t
 FileDes_fdread(FileDes *self, char *dest, u32_t dest_offset, u32_t len)
 {
-    UNUSED_VAR(self);
     UNUSED_VAR(dest);
     UNUSED_VAR(dest_offset);
     UNUSED_VAR(len);
-    CONFESS("FileDes_FDRead must be defined in a subclass");
+    ABSTRACT_DEATH(self, "FDRead");
+    UNREACHABLE_RETURN(bool_t);
 }
 
-void
-FileDes_fdwrite(FileDes *self, char* buf, u32_t len) 
+bool_t
+FileDes_fdwrite(FileDes *self, const char* buf, u32_t len) 
 {
-    UNUSED_VAR(self);
     UNUSED_VAR(buf);
     UNUSED_VAR(len);
-    CONFESS("FileDes_FDWrite must be defined in a subclass");
+    ABSTRACT_DEATH(self, "FDWrite");
+    UNREACHABLE_RETURN(bool_t);
 }
 
 u64_t
 FileDes_fdlength(FileDes *self)
 {
-    UNUSED_VAR(self);
-    CONFESS("FileDes_FDLength must be defined in a subclass");
+    ABSTRACT_DEATH(self, "FDLength");
     UNREACHABLE_RETURN(u64_t);
 }
 
-void
+bool_t
 FileDes_fdclose(FileDes *self)
 {
-    UNUSED_VAR(self);
-    CONFESS("FileDes_FDClose must be defined in a subclass");
+    ABSTRACT_DEATH(self, "FDClose");
+    UNREACHABLE_RETURN(bool_t);
 }
 
 
