@@ -18,8 +18,7 @@ OutStream_new(FileDes *file_des)
     self->is_closed   = false;
 
     /* assign */
-    REFCOUNT_INC(file_des);
-    self->file_des = file_des; 
+    self->file_des = REFCOUNT_INC(file_des); 
 
     /* increment */
     file_des->stream_count++;
@@ -53,17 +52,6 @@ OutStream_absorb(OutStream *self, InStream *instream)
     }
 }
 
-void 
-OutStream_sseek(OutStream *self, u64_t target) 
-{
-    OutStream_SFlush(self);
-    self->buf_start = target;
-    if (self->file_des->pos != target) {
-        if (!FileDes_FDSeek(self->file_des, target))
-            CONFESS("Error: %s", Carp_kerror);
-    }
-}
-
 u64_t
 OutStream_stell(OutStream *self) 
 {
