@@ -111,6 +111,8 @@ RAMFolder_rename_file(RAMFolder *self, const ByteBuf* from, const ByteBuf *to)
 
     Hash_Store_BB(self->ram_files, to, (Obj*)file_des);
     Hash_Delete_BB(self->ram_files, from);
+    free(file_des->path);
+    file_des->path = strdup(to->ptr);
 }
 
 void
