@@ -228,37 +228,39 @@ BB_ends_with_str(ByteBuf *self, const char *postfix, size_t postfix_len)
 void
 BB_serialize(ByteBuf *self, ByteBuf *target)
 {
-    size_t new_len = target->len + self->len + sizeof(u32_t);
-    char *ptr;
+    const size_t space_required = target->len + self->len + VINT_MAX_BYTES;
+    char *ptr, *start;
 
     /* make room */
-    BB_GROW(target, new_len + 1);
-    ptr = BBEND(target);
-    target->len = new_len;
+    BB_GROW(target, space_required);
+    ptr   = BBEND(target);
+    start = ptr;
 
     /* header u32_t length, followed by content */
-    MATH_ENCODE_U32(self->len, ptr);
-    ptr += sizeof(u32_t);
-    memcpy(ptr, self->ptr, self->len + 1);
+    ENCODE_VINT(self->len, ptr);
+    target->len += ptr - start;
+    memcpy(ptr, self->ptr, self->len);
+    target->len += self->len;
 }
 
 ByteBuf*
 BB_deserialize(struct kino_ViewByteBuf *serialized_vbb)
 {
     ByteBuf *const serialized_bb = (ByteBuf*)serialized_vbb;
-    u32_t size = Math_decode_bigend_u32(serialized_bb->ptr);
-    ByteBuf *self = BB_new(size);
+    u32_t size;
+    ByteBuf *self;
 
     /* copy string after verifying no invalid memory reads */
-    if (serialized_bb->len < size + sizeof(u32_t)) {
+    DECODE_VINT(size, serialized_bb->ptr);
+    if (serialized_bb->len < size) {
         CONFESS("Not enough characters in serialized object: %u %u", size,
             serialized_bb->len);
     }
-    BB_Copy_Str(self, serialized_bb->ptr + sizeof(u32_t), size);
+    self = BB_new_str(serialized_bb->ptr, size);
 
     /* consume characters */
-    serialized_bb->ptr += size + sizeof(u32_t);
-    serialized_bb->len -= (size + sizeof(u32_t));
+    serialized_bb->ptr += size;
+    serialized_bb->len -= size;
 
     return self;
 }
