@@ -67,7 +67,7 @@ VA_clone(VArray *self)
     evil_twin->size = self->size;
     for (i = 0; i < self->size; i++) {
         if (elems[i] != NULL)
-            REFCOUNT_INC(elems[i]);
+            (void)REFCOUNT_INC(elems[i]);
     }
 
     return evil_twin;
@@ -77,8 +77,7 @@ void
 VA_push(VArray *self, Obj *element) 
 {
     MAYBE_GROW(self, self->size + 1);
-    self->elems[ self->size ] = element;
-    REFCOUNT_INC(element);
+    self->elems[ self->size ] = REFCOUNT_INC(element);
     self->size++;
 }
 
@@ -96,8 +95,7 @@ VA_unshift(VArray *self, Obj *elem)
 {
     MAYBE_GROW(self, self->size + 1);
     memmove(self->elems + 1, self->elems, self->size * sizeof(Obj*));
-    self->elems[0] = elem;
-    REFCOUNT_INC(elem);
+    self->elems[0] = REFCOUNT_INC(elem);
     self->size++;
 }
 
@@ -139,8 +137,7 @@ VA_store(VArray *self, u32_t num, Obj *elem)
     else {
         self->size = num + 1;
     }
-    self->elems[num] = elem;
-    REFCOUNT_INC(elem);
+    self->elems[num] = REFCOUNT_INC(elem);
 }
 
 void
@@ -156,6 +153,17 @@ VA_grow(VArray *self, u32_t capacity)
     }
 }
 
+Obj*
+VA_delete(VArray *self, u32_t num)
+{
+    Obj *elem = NULL;
+    if (num < self->size) {
+        elem = self->elems[num];
+        self->elems[num] = NULL;
+    }
+    return elem;
+}
+
 /* Copyright 2006-2007 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
