@@ -11,10 +11,15 @@ our %instance_vars = (
     seg_info => undef,
 
     # members
-    entries => {},
+    entries => undef,
     merged  => 0,
 );
 
+sub init_instance {
+    my $self = shift;
+    $self->{entries} = {};
+}
+
 use KinoSearch::Util::Native qw( to_kino );
 use KinoSearch::Index::IndexFileNames qw( COMPOUND_FILE_FORMAT );
 
