@@ -143,7 +143,8 @@ sub unused_files {
 
 sub _seg_then_gen {
     my $filename = shift;
-    $filename =~ /^_([a-z0-9])_([a-z0-9]+)/ or confess("no match: $filename");
+    $filename =~ /^_([a-z0-9]+)_([a-z0-9]+)/
+        or confess("no match: $filename");
     my ( $seg_name, $gen ) = ( $1, $2 );
     return sprintf( "%.12d%.12d", from_base36($seg_name), from_base36($gen) );
 }
