@@ -9,11 +9,16 @@ our %instance_vars = (
     # params / members
     field         => undef,
     text          => undef,
-    positions     => [],
-    start_offsets => [],
-    end_offsets   => [],
+    positions     => undef,
+    start_offsets => undef,
+    end_offsets   => undef,
 );
 
+sub init_instance {
+    my $self = shift;
+    $self->{$_} ||= [] for qw( positions start_offsets end_offsets );
+}
+
 BEGIN {
     __PACKAGE__->ready_get_set(
         qw(
