@@ -7,12 +7,18 @@ use base qw( KinoSearch::Search::Filter );
 
 our %instance_vars = (
     # inherited
-    cached_bits => {},
+    cached_bits => undef,
 
     # members
-    filters => [],
+    filters => undef,
 );
 
+sub init_instance {
+    my $self = shift;
+    $self->{cached_bits} = {};
+    $self->{filters}     = [];
+}
+
 sub bits {
     my ( $self, $reader ) = @_;
 
