@@ -52,7 +52,7 @@ PPCODE:
     case 1:  REFCOUNT_DEC(self->sim);
              EXTRACT_STRUCT( ST(1), self->sim, kino_Similarity*, 
                 "KinoSearch::Search::Similarity" );
-             REFCOUNT_INC(self->sim);
+             (void)REFCOUNT_INC(self->sim);
              break;
 
     case 2:  retval = self->sim  == NULL
