@@ -123,7 +123,10 @@ sub do_top_docs {
     my ( $self, $args ) = @_;
     confess("remote filtered search not supported")
         if defined $args->{filter};
-    return $self->{searchable}->top_docs(%$args);
+    my $top_docs = $self->{searchable}->top_docs(%$args);
+    $top_docs->remotify($args->{sort_spec}, $self->{searchable}->get_reader)
+        if $args->{sort_spec};
+    return $top_docs;
 }
 
 sub do_max_doc {
