@@ -149,7 +149,7 @@ scores is encapsulated within the Similarity class.
 
 Similarity objects are are used internally by KinoSearch's indexing and
 scoring classes.  They are assigned using L<KinoSearch::Schema> and
-L<KinoSearch::Schema::FieldSpec>.
+L<KinoSearch::FieldSpec>.
 
 Only one method is publicly exposed at present.
 
