@@ -35,13 +35,6 @@ PPCODE:
     }
 }
 
-void
-sseek(self, target)
-    kino_OutStream *self;
-    chy_u64_t       target;
-PPCODE:
-    Kino_OutStream_SSeek(self, target);
-
 
 chy_u64_t
 stell(self)
